Pompei
=================

Pompei (documentation and examples here_) is a python package and command line utility to generate photo mosaics from movie frames,
like this one:

.. image:: http://i.imgur.com/fQ8QlJ8.jpg
   :alt: [example]
   :align: center
   :width: 500 px

It is an open-source software originally written by Zulko_ and released under the MIT licence. Everyone is welcome to contribute or ask for support on the Github_ project page.

Installation
--------------

If you have PIP installed: ::

    (sudo) pip install ez_setup pompei

Or unzip the source code in a directory and type in a terminal: ::

    sudo python setup.py install

.. _Zulko: https://github.com/Zulko/
.. _here: http://zulko.github.io/pompei
.. _MoviePy: http://zulko.github.io/moviepy
.. _Github: https://github.com/Zulko/pompei